#ifndef _GENERATE_KING_WALK_H
#define _GENERATE_KING_WALK_H
#include "osl/move_generator/pieceOnBoard.h"
//#include "osl/state/simpleState.h"
namespace osl
{
  namespace move_generator
  {
    template <Player P>
    struct KingWalk
    {
      template <class Action>
      static void generate(const NumEffectState& state, Action& action)
      {
	PieceOnBoard<Action>::template generatePtype<P,KING>(state,state.kingPiece<P>(),action);
      }
      
    };
  }
} // namespace osl

#endif /* _GENERATE_KING_WALK_H */
// ;;; Local Variables:
// ;;; mode:c++
// ;;; c-basic-offset:2
// ;;; End:
